@@ -101,7 +101,8 @@ fn impl_checkout_server(ast: &DeriveInput) -> TokenStream {
 
             pub struct Config {
                 pub google_application_credentials: String,
-                pub payment_processing_topic: String
+                pub payment_processing_topic: String,
+                pub checkout_completion_topic: String,
             }
 
             pub fn get_config() -> Config {
